import React from "react";
import { NWFilter } from "../../api/NWFilterApi";
import { NWFilterSelectInput } from "./NWFilterSelectInput";
import { NWFilterItem } from "../nwfilter/NWFilterItem";

export function NWFSelectReferencedFilters(p: {
  editable: boolean;
  selected: string[];
  nwFiltersList: NWFilter[];
  onChange?: () => void;
  excludedFilters?: string[];
}): React.ReactElement {
  const nwfilters = React.useMemo(
    () =>
      p.excludedFilters
        ? p.nwFiltersList.filter((f) => !p.excludedFilters!.includes(f.name))
        : p.nwFiltersList,
    [p.excludedFilters]
  );

  const selectedFilters = React.useMemo(
    () => p.selected.map((f) => p.nwFiltersList.find((s) => s.name === f)),
    [p.selected.length]
  );

  return (
    <>
      {selectedFilters.map((entry, n) => (
        <NWFilterItem
          key={n}
          value={entry}
          onDelete={() => {
            p.selected.splice(n, 1);
            p.onChange?.();
          }}
        />
      ))}

      {p.editable && (
        <NWFilterSelectInput
          editable={p.editable}
          label="Attach a new filter"
          canBeNull={false}
          nwfilters={nwfilters}
          value={""}
          onChange={(f) => {
            p.selected.push(f!);
            p.onChange?.();
          }}
        />
      )}
    </>
  );
}
